@@ -1,8 +1,12 @@
 import os
 from pathlib import Path
-
 import click
 
+try:
+	from ProjectAliceSK.makeTalks import TalkCreator
+except:
+	from makeTalks import TalkCreator
+
 
 @click.command()
 @click.option('-s', '--skill', required=True, help='The skill name to work on', type=str, prompt='For what skill name?')
@@ -19,6 +23,9 @@ def makeTalks(skill: str, lang: str):
 
 	skillPath = skillPath / skill
 
+	copy2talk = TalkCreator.CopyTooTalk()
+	copy2talk.checkForLogInfo(skill=skillPath, language=lang)
+
 
 if __name__ == '__main__':
 	# pylint: disable=no-value-for-parameter
